### INTERLACE_Check

##### Introduction

INTERLACE_Check.py will help to the treatment between slices by rule out weird volumes with statistical conditions

##### Protocol Parameters

- correlationThresholdBaseline is a float with a default value of 0.9500, it will check the correlation threshold of the baselines

- correlationThresholdGradient is a float with a default value of 0.7702, it will check the correlation threshold of the gradients

- correlationDeviationBaseline is a float with a default value of 2.5000, it will check the correlation deviation of the baselines

- correlationDeviationGradient is a float with a default value of 3.0000, it will check the correlation deviation of the gradients

- translationThreshold is a float with a default value of 1.5000, it will check the translation threshold

- rotationThreshold is a float with a default value of 0.5000, it will check the rotation threshold

##### Examples


##### Author(s)

